@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #include "filtermailapptest.h"
 #include <MailImporter/FilterMailApp>
 #include "filterimportertest.h"
-#include <qtest.h>
+#include <QTest>
 
 FilterMailAppTest::FilterMailAppTest(QObject *parent)
     : QObject(parent)
